summaryrefslogtreecommitdiff
path: root/src/mongo/db/commands/find_cmd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/commands/find_cmd.cpp')
-rw-r--r--src/mongo/db/commands/find_cmd.cpp21
1 files changed, 10 insertions, 11 deletions
diff --git a/src/mongo/db/commands/find_cmd.cpp b/src/mongo/db/commands/find_cmd.cpp
index 983661fbd15..90e6fa15ca1 100644
--- a/src/mongo/db/commands/find_cmd.cpp
+++ b/src/mongo/db/commands/find_cmd.cpp
@@ -55,7 +55,7 @@
#include "mongo/db/query/find_request_shapifier.h"
#include "mongo/db/query/get_executor.h"
#include "mongo/db/query/query_knobs_gen.h"
-#include "mongo/db/query/query_stats.h"
+#include "mongo/db/query/telemetry.h"
#include "mongo/db/repl/replication_coordinator.h"
#include "mongo/db/s/query_analysis_writer.h"
#include "mongo/db/service_context.h"
@@ -561,14 +561,13 @@ public:
cq->setUseCqfIfEligible(true);
if (collection) {
// Collect queryStats. Exclude queries against collections with encrypted fields.
if (!collection.get()->getCollectionOptions().encryptedFieldConfig) {
- query_stats::registerRequest(
- std::make_unique<query_stats::FindRequestShapifier>(
- cq->getFindCommandRequest(), opCtx),
- collection.get()->ns(),
- opCtx,
- cq->getExpCtx());
+ telemetry::registerRequest(std::make_unique<telemetry::FindRequestShapifier>(
+ cq->getFindCommandRequest(), opCtx),
+ collection.get()->ns(),
+ opCtx,
+ cq->getExpCtx());
}
}
@@ -781,9 +780,9 @@ public:
processFLEFindD(
opCtx, findCommand->getNamespaceOrUUID().nss().value(), findCommand.get());
}
- // Set the queryStatsStoreKey to none so queryStats isn't collected when we've done
- // a FLE rewrite.
- CurOp::get(opCtx)->debug().queryStatsStoreKeyHash = boost::none;
+ // Set the telemetryStoreKey to none so telemetry isn't collected when we've done a
+ // FLE rewrite.
+ CurOp::get(opCtx)->debug().telemetryStoreKeyHash = boost::none;
CurOp::get(opCtx)->debug().shouldOmitDiagnosticInformation = true;
}
@@ -561,14 +561,13 @@ public:
cq->setUseCqfIfEligible(true);
if (collection) {
- // Collect queryStats. Exclude queries against collections with encrypted fields.
+ // Collect telemetry. Exclude queries against collections with encrypted fields.
if (!collection.get()->getCollectionOptions().encryptedFieldConfig) {